==> estateplat-common-1.2.3-20180122.024348-19-sources.jar: cn/gtmap/estateplat/model/commodityHouse/projectManage/FcjyXjspfh.java <==
package cn.gtmap.estateplat.model.commodityHouse.projectManage;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-12-12
 * @description 新建商品房户表
 */
@Table(name = "fcjy_xjspf_h")
public class FcjyXjspfh {
    @Id
    private String hid;//户ID
    private String hbh;//户编号（房屋编号）
    private String bdcdyh;//不动产单元号
    private String zrzh;//自然幢号（关联自然幢信息）
    private String ljzh;//逻辑幢号（关联逻辑幢信息）
    private String ljzid;//逻辑幢ID
    private String xmid;//项目ID(关联开发项目)
    private String xkid;//预售许可ID(关联预售许可)
    private String ch;//层号
    private String zl;//坐落
    private String fjh;//房间号
    private String fwxz;//房屋性质（不动产登记房屋性质字典项）
    private String fwyt;//房屋用途（房屋用途字典表）
    private Double jzmj;//建筑面积(平方米)
    private Double sbjgm;//申报价格按平方米
    private Double sbjgt;//申报价格按套
    private Double cjjg;//成交价格（元/平方米）
    private String sfks;//是否可售（0或空不可售1可以销售）
    private String sfys;//是否已售（0或空没销1已售2草签）
    private String yflx;//用房类型(1：物管用房:2：安置房:3：保留房)
    private String sfptzz;//是否普通住宅(0或空是，1不是)
    private String sfdj;//是否冻结(0或空不是，1是)

    public String getHid() {
        return hid;
    }

    public void setHid(String hid) {
        this.hid = hid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getLjzh() {
        return ljzh;
    }

    public void setLjzh(String ljzh) {
        this.ljzh = ljzh;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getXkid() {
        return xkid;
    }

    public void setXkid(String xkid) {
        this.xkid = xkid;
    }

    public String getCh() {
        return ch;
    }

    public void setCh(String ch) {
        this.ch = ch;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getFwyt() {
        return fwyt;
    }

    public void setFwyt(String fwyt) {
        this.fwyt = fwyt;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getSbjgm() {
        return sbjgm;
    }

    public void setSbjgm(Double sbjgm) {
        this.sbjgm = sbjgm;
    }

    public Double getSbjgt() {
        return sbjgt;
    }

    public void setSbjgt(Double sbjgt) {
        this.sbjgt = sbjgt;
    }

    public Double getCjjg() {
        return cjjg;
    }

    public void setCjjg(Double cjjg) {
        this.cjjg = cjjg;
    }

    public String getSfks() {
        return sfks;
    }

    public void setSfks(String sfks) {
        this.sfks = sfks;
    }

    public String getSfys() {
        return sfys;
    }

    public void setSfys(String sfys) {
        this.sfys = sfys;
    }

    public String getYflx() {
        return yflx;
    }

    public void setYflx(String yflx) {
        this.yflx = yflx;
    }

    public String getSfptzz() {
        return sfptzz;
    }

    public void setSfptzz(String sfptzz) {
        this.sfptzz = sfptzz;
    }

    public String getSfdj() {
        return sfdj;
    }

    public void setSfdj(String sfdj) {
        this.sfdj = sfdj;
    }

    public String getLjzid() {
        return ljzid;
    }

    public void setLjzid(String ljzid) {
        this.ljzid = ljzid;
    }
}

==> estateplat-common-1.2.3-20180314.020348-43-sources.jar: cn/gtmap/estateplat/model/commodityHouse/projectManage/FcjyXjspfh.java <==
package cn.gtmap.estateplat.model.commodityHouse.projectManage;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-12-12
 * @description 新建商品房户表
 */
@Table(name = "fcjy_xjspf_h")
public class FcjyXjspfh {
    @Id
    private String hid;//户ID
    private String hbh;//户编号（房屋编号）
    private String bdcdyh;//不动产单元号
    private String zrzh;//自然幢号（关联自然幢信息）
    private String ljzh;//逻辑幢号（关联逻辑幢信息）
    private String ljzid;//逻辑幢ID
    private String xmid;//项目ID(关联开发项目)
    private String xkid;//预售许可ID(关联预售许可)
    private String ch;//层号
    private String zl;//坐落
    private String fjh;//房间号
    private String fwxz;//房屋性质（不动产登记房屋性质字典项）
    private String fwyt;//房屋用途（房屋用途字典表）
    private Double jzmj;//建筑面积(平方米)
    private Double sbjgm;//申报价格按平方米
    private Double sbjgt;//申报价格按套
    private Double cjjg;//成交价格（元/平方米）
    private String sfks;//是否可售（0或空不可售1可以销售）
    private String sfys;//是否已售（0或空没销1已售2草签）
    private String yflx;//用房类型(1：物管用房:2：安置房:3：保留房)
    private String sfptzz;//是否普通住宅(0或空是，1不是)
    private String sfdj;//是否冻结(0或空不是，1是)
    private String ysc;//（YC：预测 SC：实测 ）
    private String fwbm;//房屋编码
    private String ycfwbm;//预测房屋编码


    public String getHid() {
        return hid;
    }

    public void setHid(String hid) {
        this.hid = hid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getLjzh() {
        return ljzh;
    }

    public void setLjzh(String ljzh) {
        this.ljzh = ljzh;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getXkid() {
        return xkid;
    }

    public void setXkid(String xkid) {
        this.xkid = xkid;
    }

    public String getCh() {
        return ch;
    }

    public void setCh(String ch) {
        this.ch = ch;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getFwyt() {
        return fwyt;
    }

    public void setFwyt(String fwyt) {
        this.fwyt = fwyt;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getSbjgm() {
        return sbjgm;
    }

    public void setSbjgm(Double sbjgm) {
        this.sbjgm = sbjgm;
    }

    public Double getSbjgt() {
        return sbjgt;
    }

    public void setSbjgt(Double sbjgt) {
        this.sbjgt = sbjgt;
    }

    public Double getCjjg() {
        return cjjg;
    }

    public void setCjjg(Double cjjg) {
        this.cjjg = cjjg;
    }

    public String getSfks() {
        return sfks;
    }

    public void setSfks(String sfks) {
        this.sfks = sfks;
    }

    public String getSfys() {
        return sfys;
    }

    public void setSfys(String sfys) {
        this.sfys = sfys;
    }

    public String getYflx() {
        return yflx;
    }

    public void setYflx(String yflx) {
        this.yflx = yflx;
    }

    public String getSfptzz() {
        return sfptzz;
    }

    public void setSfptzz(String sfptzz) {
        this.sfptzz = sfptzz;
    }

    public String getSfdj() {
        return sfdj;
    }

    public void setSfdj(String sfdj) {
        this.sfdj = sfdj;
    }

    public String getLjzid() {
        return ljzid;
    }

    public void setLjzid(String ljzid) {
        this.ljzid = ljzid;
    }

    public String getYsc() {
        return ysc;
    }

    public void setYsc(String ysc) {
        this.ysc = ysc;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }

    public String getYcfwbm() {
        return ycfwbm;
    }

    public void setYcfwbm(String ycfwbm) {
        this.ycfwbm = ycfwbm;
    }
}
